@@ -8,6 +8,13 @@ from Fishconsole import window
 from Fishconsole import fcv
 from Fishconsole import Fishsys
 
+
+
+
+
+
+
+
 sys = fcv.f_debug()
 sys = sys["updata"]
 UPI = fcv.f_debug()
@@ -60,8 +67,7 @@ def 帮助():
                     config["updata"] = True
                     Fishsys.缓存(1, config)
                 Fishsys.缓存(1, config)
-                logs.系统日志(f"Fishconsole》help》强制更新启动")
-                exit()
+                logs.安全退出(f"Fishconsole》help》强制更新启动")
             else:
                 logs.日志(f"Fishconsole》f_debug》已取消强制更新", "绿色")
                 # 尝试获取缓存中的值
@@ -89,12 +95,11 @@ def 帮助():
         print(logs.日志(f"Fishconsole{fcv.version()} 检查更新结束"))
         print(logs.日志("你的设备无法访问互联网，请检查网络连接"))
 
-    help_mod = logs.输入("如果您使用termux安装的话，请按1，否则按2")
-    if help_mod == "1":
-        print(logs.日志("termux支持已被取消", "红色"))
-        exit()
-    else:
+    help_mod = logs.输入(f"这是Fishconsole的开发文档，如果想查看，请按任意字符开始")
+    if True:
         res = window.列表选择对话框(
+            "我如何重新进入？\n"
+            "导入helps包，然后键入helps.帮助()就可以回来了\n\n"
             "关于控制台输出模块的帮助文档会显示在命令行中，选中你想查看的内容，我们将会提供相应的窗口。\n\n"
             "为什么有的地方找不到? \n"
             "因为我没做哈欠。\n\n"
@@ -105,8 +110,7 @@ def 帮助():
             ["Matplotlib中文辅助模块", "easygui中文辅助模块", "logs控制台输出辅助模块", "Fishsys模块"])
         logs.系统日志(f"用户请求启动{res}")
         if res == None:
-            print(logs.日志("用户取消了操作", "红色"))
-            exit()
+            logs.安全退出("用户取消了操作")
         if res is not None:
             for a in res:
                 if a == "logs控制台输出辅助模块":
@@ -360,8 +364,7 @@ def 帮助():
                     ])
                     logs.系统日志(f"用户请求启动{res}")
                     if res == None:
-                        print(logs.日志("用户取消了操作", "红色"))
-                        exit()
+                        logs.安全退出("用户取消了操作")
                     for a in res:
                         if a == "密码模块":
                             window.弹窗(
